# Boost Graph Library Users

This is a list of people, projects, courses, companies, and other languages that are using the Boost Graph Library in some way, shape, or form.

If you are using the BGL and want to be listed here, please send mail to the Boost Users mailing list!

- Generic Software Design Course at RPI
- The ALPS quantum mechanics project
- Large Graph Layout at University of Texas
- Bioinformatics Algorithms at Concordia University
- Algorithm Course at Polytechnic University in Brooklyn
- BGL interface for language R.
- CUJ Article about Electronic Design Automation
- A BGL-inspired Ruby Graph Library
- A BGL-inspired C# Graph Library
- A BGL-inspired Squeak (Smalltalk) Graph Library
- BGL course at DataSim
- VR Juggler: Virtual Reality Tools
- Hyperworx Platform Project
- OpenCog, an open source Artificial General Intelligence framework